@@ -2,4 +2,4 @@ module HaskellWorks.Data.Json.Internal.Token
   ( module X
   ) where
 
-import HaskellWorks.Data.Json.Internal.Token.Tokenize as X
+import HaskellWorks.Data.Json.Internal.Standard.Token.Tokenize as X
